<?php
/**
 * Plugin Name: ContentRaccoon | AI Powered SEO Optimized Content Generator For WP using GPT-4
 * Description: Create High-Quality Content with AI and GPT-4 on WP
 * Version: 1.0
 * Author: <a href="https://contentraccoon.com/" target=_blank>ContentRaccoon.com</a>
 */


define( 'contentraccoon_PLUGIN_DIR', plugin_dir_path( __FILE__ ) ); 
define( 'contentraccoon_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

include_once contentraccoon_PLUGIN_DIR . 'inc/contentraccoon-api.php';
include_once contentraccoon_PLUGIN_DIR . 'inc/contentraccoon-html.php';
include_once contentraccoon_PLUGIN_DIR . 'inc/contentraccoon-generals.php';

 

add_action( 'admin_enqueue_scripts', 'contentraccoon_enqueue_admin_styles' );
function contentraccoon_enqueue_admin_styles() {

    // Get the current screen object
    $screen = get_current_screen(); 

    // Enqueue styles only on the new post screen and the plugin settings screen
    if ( $screen->id == 'post' || $screen->id == 'settings_page_contentraccoon' ) {

        // Enqueue custom admin stylesheet
        wp_enqueue_style( 'contentraccoon-admin-styles', contentraccoon_PLUGIN_URL . '/css/contentraccoon-admin.css?v='.time() );

        // Enqueue Typekit fonts stylesheet
        wp_enqueue_style( 'contentraccoon-fonts-1', 'https://use.typekit.net/vyh6fdd.css');
        wp_enqueue_style( 'contentraccoon-fonts-2', 'https://fonts.googleapis.com/css2?family=Playfair+Display:wght@400;500;600;700;800;900&display=swap');
		
		wp_enqueue_script( 'contentraccoon-js', contentraccoon_PLUGIN_URL . 'js/contentraccoon-js.js?v='.time(), array( 'jquery' ), '1.0.0', true );
		wp_localize_script( 'contentraccoon-js', 'contentraccoon_ajax_obj', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

    }

}


function contentraccoon_settings_page_render() {
    if (!current_user_can('manage_options')) {
        return;
    }

    $user_credits = contentraccoon_get_credits();
    $email = get_option('contentraccoon_email');
    $user_token = get_option('contentraccoon_user_token');

    if (isset($_POST['email']) && isset($_POST['user_token'])) {
        $email = sanitize_email($_POST['email']);
        $user_token = sanitize_text_field($_POST['user_token']);

        if (!is_email($email)) {
            echo '<div class="error"><p>Invalid email address</p></div>';
            return;
        }

        $website_token = contentraccoon_login($email, $user_token);

        if (!$website_token) {
            echo '<div class="error"><p>Error logging in. Please check your email and user token. <a href="https://members.contentraccoon.com/" target="_blank">Click here to check your credentials</a></p></div>';
            return;
        }

        update_option('contentraccoon_email', $email);
        update_option('contentraccoon_user_token', $user_token);
        update_option('contentraccoon_website_token', $website_token);
    }

    $website_token = get_option('contentraccoon_website_token');
    $validate_token = contentraccoon_validate_token($website_token);

    if ($website_token && !$validate_token) {
        delete_option('contentraccoon_website_token');
        delete_option('contentraccoon_user_token');
        delete_option('contentraccoon_email');
        $website_token = false;
    }
	
	?>
	<div id="contentraccoon-wrapper">
		
		<div class="contentraccoon-inner">
			<div class="contentraccoon-header">
				<div class="header-logo">
					<a href="https://contentraccoon.com/" target="_blank">
						<span class="ia">C</span><span class="io">o</span><span class="ia">n</span><span class="io">t</span><span class="ia">e</span><span class="io">n</span><span class="ia">t</span><span class="io">R</span><span class="ia">a</span><span class="io">c</span><span class="ia">c</span><span class="io">o</span><span class="ia">o</span><span class="io">n</span>
					</a>
				</div>
			</div>
			<div class="side-1">
				<div class="sidebox">
					<div class="wrap">
						<?php if (!$website_token) : ?>
							<h2>Login to ContentRaccoon Account</h2>
							<form method="post">
								<table class="form-table">
									<tbody>
										<tr>
											<th scope="row">
												<label for="email">Email</label>
											</th>
											<td>
												<input name="email" type="email" id="email" value="<?php echo esc_attr($email); ?>">
											</td>
										</tr>
										<tr>
											<th scope="row">
												<label for="user_token">User Token</label>
											</th>
											<td>
												<div style="position:relative;">
													<input name="user_token" type="text" id="user_token">
													<a href="https://contentraccoon.com/dashboard/" target="_blank"><button class="button blue">Get Token</button></a>
												</div>
											</td>
										</tr>
									</tbody>
								</table>
								<p class="submit">
									<input type="submit" name="submit" id="submit" class="button blue" value="Connect"/>
								</p>
							</form>
						<?php else : ?> 
							<p>
								You are now logged in!
								<br /> 
								Go to the "Add New" post screen to use ContentRaccoon post creator.
							</p>
							<div class="credit-count">You have <span><?php echo esc_html(number_format($user_credits)); ?> Credits</span> <small>1 Credit = 1 Word</small></div>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<div class="side-2">
				<div class="sidebox">
					<div class="contentraccoon-menu">
						<div class="contentraccoon-menuitem"><a href="https://contentraccoon.com/" target="_blank">Go to ContentRaccoon.com</a></div>
						<div class="contentraccoon-menuitem"><a href="https://contentraccoon.com/dashboard/" target="_blank">Go to Members Area</a></div>
						<div class="contentraccoon-menuitem"><a href="https://contentraccoon.com/#pricing" target="_blank">Add More Credits</a></div>
						<div class="contentraccoon-menuitem"><a href="https://twitter.com/_ContentRaccoon" target="_blank">Get Support</a></div>
					</div> 
				</div>
				<div class="cr">
					<img src="https://contentraccoon.com/images/raccoon_super.jpg" alt="" class="">
				</div>
			</div>
		</div>
	</div>
	<?php

}


function add_html_to_post_screen() {
	
	
	$keywordQuotes = array(
		"We're busy generating some post subjects, just for you!",
		"Creating post subjects takes time, but it's worth it.",
		"Get ready to discover some exciting new post subjects!",
		"Don't worry, we're on it - your post subjects will be ready soon.",
		"Creating post subjects is an art form - and we're the artists!",
		"We're generating some fantastic post subjects just for you - stay tuned!",
		"The process of creating post subjects is fascinating - and you're about to see why.",
		"Our team is hard at work creating the best possible post subjects for you.",
		"Creating post subjects is like mining for gold - it takes time, but the results are worth it."
	);
	$keywordQuotes_quote = $keywordQuotes[rand(0,count($keywordQuotes)-1)];
	
	
	$titleQuotes = array(
		"Get ready for some amazing post titles - we're on it!",
		"Creating post titles is an art form - and we're the artists!",
		"Making up post titles is an exciting challenge - and we're up for it!",
		"We're busy brainstorming some fantastic post titles for you - stay tuned!",
		"Creating the perfect post title takes time, but it's worth it.",
		"The process of making up post titles is fascinating - and you're about to see why.",
		"Don't worry, we're hard at work creating the best possible post titles for you.",
		"Get ready to be blown away by our amazing post titles!",
		"Our team is dedicated to making up the most engaging and attention-grabbing post titles for you."
	);
	$titleQuotes_quote = $titleQuotes[rand(0,count($titleQuotes)-1)];
	
	
	$tailoringQuotes = array(
		"We're putting together something unique, just for you.",
		"Creating a personalized experience takes time, but we're working hard to make it happen.",
		"Your customized experience is on its way - get ready to be impressed!",
		"Creating something that's perfectly suited to you is our top priority.",
		"We're crafting something special that's tailored to your unique needs and preferences.",
		"Don't worry - we're working tirelessly to create an unforgettable experience just for you.",
		"Get ready for something that's truly one-of-a-kind - it's coming soon!",
		"Creating a personalized experience is a complex process, but we're up for the challenge.",
		"We're proud to be creating something that's not only tailored to you, but also truly exceptional."
	);
	$tailoringQuotes_quote = $tailoringQuotes[rand(0,count($tailoringQuotes)-1)];
	
	
    ?>

	<div id="contentraccoon-create">
		
		<div id="contentraccoon-progressbar" data-progress="-1" data-progress-label="">
			<div class="contentraccoon-progress-inner">
				<div class="contentraccoon-progress-inner-bar"></div>
			</div>
		</div>
		
		<div id="contentraccoon__creator-form" >
			 
			<input type="hidden" name="contentraccoon_post_token" id="contentraccoon_post_token" value="" />
			<input type="hidden" name="contentraccoon_step_number" id="contentraccoon_step_number" value="1" />
			
			<div id="contentraccoon__creator" data-step="1" class="loading">


				<?php echo contentraccoon_loader_html(); ?>
				
				<div class="creator-topper">
				 
					<a class="loader-text-1" href="https://contentraccoon.com/" target=_blank>
						<span class="ia">C</span><span class="io">o</span><span class="ia">n</span><span class="io">t</span><span class="ia">e</span><span class="io">n</span><span class="ia">t</span><span class="io">R</span><span class="ia">a</span><span class="io">c</span><span class="ia">c</span><span class="io">o</span><span class="ia">o</span><span class="io">n</span>
					</a>
					
					<div class="contentraccoon-close"><span></span></div>
				
				</div>

				<div class="creator-menu">

					<div class="creator-menu-item active" data-id="1" data-loader="<?php echo $keywordQuotes_quote; ?>" data-next="Select Key Points" data-prev="">
						<div class="creator-menu-item--label">Basic Settings</div>
						<div class="step-data">
							<div class="step-data-line" data-field="contentraccoon_subject" style="display:none;">
								<label>Primary Keyword</label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="contentraccoon_format_type" style="display:none;">
								<label>Post Type</label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="contentraccoon_length" style="display:none;">
								<label>Word Length</label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="contentraccoon_audience" style="display:none;">
								<label>Target Audience</label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="contentraccoon_purpose" style="display:none;">
								<label>Main Purpose</label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="contentraccoon_tone" style="display:none;">
								<label>Tone</label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="2" data-loader="<?php echo $titleQuotes_quote; ?>" data-next="Select Post Title" data-prev="Modify Basics">
						<div class="creator-menu-item--label">Key Points</div>
						<div class="step-data">
							<div class="step-data-line" data-field="contentraccoon_keywords" style="display:none;">
								<label>Key Points</label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="3" data-loader="<?php echo $tailoringQuotes_quote; ?>" data-next="Review Post" data-prev="Modify Key Points">
						<div class="creator-menu-item--label">Post Title</div>
						<div class="step-data">
							<div class="step-data-line" data-field="contentraccoon_post_title" style="display:none;">
								<label>Post Title</label>
								<span></span>
							</div>
						</div>
					</div>
					<!--<div class="creator-menu-item" data-id="4" data-loader="Wrapping it up..." data-prev="Back to titles" data-next="Final Review">Sections Structure</div>-->
					<div class="creator-menu-item" data-id="4" data-loader="Sending to the Raccoon!" data-next="Yes, I confirm: Create Post" data-prev="Reselect Title">
						<div class="creator-menu-item--label">Post Review</div>
						<div class="step-data">
							<div class="step-data-line" data-field="" style="display:none;">
								<label></label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="5" data-prev="" data-next="">
						<div class="creator-menu-item--label">Post Creation</div>
						<div class="step-data">
							<div class="step-data-line" data-field="" style="display:none;">
								<label></label>
								<span></span>
							</div>
						</div>
					</div>
					
				</div>

				<div class="creator-steps">

					<div class="creator-steps-inner">

						<div class="creator-step active" data-id="1">

							<h3>Basic Settings</h3>
							
							<div class="form-input">
								<label>
									Primary Keyword(s) <span class="required">required</span>
								</label>
								<div class="exp">
									Enter the keyword or the phrase you'd like to post about.
									<br/>We will suggest relevant titles and additional sub keywords according to that.
								</div>
								<input type="text" name="contentraccoon_subject" id="contentraccoon_subject"  value="" />
							</div>
	 
							<div class="form-input">
								<label>
									Post Type <span class="required">required</span>
								</label>
								<div class="exp">The post type is important to determine its structure, headings and content, and to give you better suggestions in the process.</div>
								<select name="contentraccoon_format_type" id="contentraccoon_format_type"onchange='jQuery(this).parent().find(".miniinfo").text(jQuery(this).find("option:selected").attr("data-info"))'>
									<option value="" disabled selected>Select post type...</option>
									<?php
									$post_types = contentraccoon_get_post_types(); 
									foreach ($post_types  as $key => $value) {
										echo '<option value="' . esc_attr($key) . '" data-info="' . esc_attr($value['description']) . '">' . esc_attr($value['label']) . '</option>';
									} 
									?>
								</select>
								<span class="miniinfo"></span>
							</div>

							<div class="form-input">
								<label>
									Word Length
								</label>
								<div class="exp">How many words do you want the post to be?</div>
								<input type="number" value="1500" min="250" max="3000" step="250" name="contentraccoon_length" id="contentraccoon_length" />
							</div>
							
							
							<div class="form-input">
								<label>
									Target Audience
								</label>
								<div class="exp">In simple words, who's the audience of your post?</div>
								<input type="text" name="contentraccoon_audience" id="contentraccoon_audience" placeholder="Enter age range, sex, interests, etc, or just 'all'" value="" />
							</div>
							
							<div class="form-input">
								<label>
									Main Purpose
								</label>
								<div class="exp">In simple words, what's the purpose of your post?</div>
								<input type="text" name="contentraccoon_purpose" id="contentraccoon_purpose" placeholder="To sell, to promote, to research, to enrich about... or just 'general'" value="" />
							</div>
							 
							<div class="form-input">
								<label>
									Tone
								</label>
								<div class="exp">Select tone of writing</div>
								<select name="contentraccoon_tone" id="contentraccoon_tone" onchange='jQuery(this).parent().find(".miniinfo").text(jQuery(this).find("option:selected").attr("data-info"))'>
								  <option value="" disabled selected>Select Tone</option>
								  <optgroup label="General">
									<option value="informative" selected data-info="Neutral and informative">Informative</option>
									<option value="friendly" data-info="Casual and conversational">Friendly</option>
									<option value="authoritative" data-info="Confident and knowledgeable">Authoritative</option>
									<option value="thoughtful" data-info="Introspective and contemplative">Thoughtful</option>
								  </optgroup>
								  <optgroup label="Casual">
									<option value="inviting" data-info="Friendly and inviting">Inviting</option>
									<option value="direct" data-info="Simple and direct">Direct</option>
									<option value="gentle" data-info="Calm and gentle">Gentle</option>
									<option value="curious" data-info="Curious and questioning">Curious</option>
									<option value="relaxed" data-info="Laid back and relaxed">Relaxed</option>
									<option value="tactful" data-info="Tactful and diplomatic">Tactful</option>
								  </optgroup>
								  <optgroup label="Detailed">
									<option value="descriptive" data-info="Detailed and descriptive">Descriptive</option>
									<option value="concise" data-info="Crisp and concise">Concise</option>
								  </optgroup>
								  <optgroup label="Professional">
									<option value="business-like" data-info="Formal and serious">Business-like</option>
									<option value="technical" data-info="Precise and technical">Technical</option>
									<option value="academic" data-info="Scholarly and researched">Academic</option>
									<option value="polished" data-info="Refined and sophisticated">Polished</option>
									<option value="structured" data-info="Organized and systematic">Structured</option>
								  </optgroup>
								  <optgroup label="Persuasive">
									<option value="respectful" data-info="Polite and self-assured">Respectful</option>
									<option value="persuasive" data-info="Powerful and convincing">Persuasive</option>
									<option value="motivational" data-info="Encouraging and inspiring">Motivational</option>
									<option value="assertive" data-info="Forceful and confident">Assertive</option>
								  </optgroup>
								  <optgroup label="Emotional">
									<option value="excited" data-info="Enthusiastic and energetic">Excited</option>
									<option value="optimistic" data-info="Positive and hopeful">Optimistic</option>
									<option value="passionate" data-info="Intense and emotional">Passionate</option>
									<option value="compassionate" data-info="Empathetic and caring">Compassionate</option>
									<option value="sincere" data-info="Genuine and heartfelt">Sincere</option>
									<option value="skeptical" data-info="Doubting and critical">Skeptical</option>
									<option value="inspired" data-info="Motivated and uplifting">Inspired</option>
									<option value="determined" data-info="Resolute and focused">Determined</option>
								  </optgroup>
								  <optgroup label="Humorous">
									<option value="sarcastic" data-info="Witty and biting">Sarcastic</option>
									<option value="humorous" data-info="Lighthearted and funny">Humorous</option>
									<option value="ironic" data-info="Opposite of expectations">Ironic</option>
								  </optgroup>
								</select> 
								<span class="miniinfo"></span>
							</div>
							 
							
						</div> 

						<div class="creator-step" data-id="2">
							
							<h3>Key Points</h3>
							
							<div class="form-input" id="contentraccoon_keywords_container">
								<label>
									Suggested Key Points
								</label>
								<div class="exp">
									Select the key points to focus in the post content. You can also add more of yours.
								</div>
								<div class="post-keywords">
								
								</div>
								 
								<h4>Manual Key Points</h4>
								<div class="exp">If you'd like the post to focus specific key points of your own, enter them and separate with commas (,).</div>
								<input type="text" name="contentraccoon_manual_keywords" id="contentraccoon_manual_keywords"  value="" placeholder="Key Point 1, Key Points 2, ..." />
							</div>
							
						</div>
						
						<div class="creator-step" data-id="3">

							<h3>Post Title</h3>

							<div class="form-input">
								<div class="exp">
									Use your own post title or select one of our great recommendations below. 
								</div>
								<input type="text" name="contentraccoon_post_title" id="contentraccoon_post_title"  value="" />
								
								<h4>
									<span>Our Suggestions</span>
									<div class="autogen-button"><i class="fa-regular fa-wand-magic-sparkles"></i>Regenerate Suggestions</div>
								</h4>
								
								<div class="post-ideas">
								
								</div>
							</div>
							
						</div>

						<!--
						<div class="creator-step" data-id="4">
							
							<h3>Sections Structure</h3>
							
							<div class="form-input" id="post_sections">
								<label>
									<span>Section Headings</span>
									<div class="autogen-button"><i class="fa-regular fa-wand-magic-sparkles"></i>Make Suggestions</div>
								</label>
								<div class="exp">
									According to the details you provided, here's a post structure tailored for you.
								</div>
								
								<div class="post-sections">

									<div class="repeater repeater-sectionheadings">

										<div class="repeater-row" data-original data-id="1">
											<div class="form-input" style="margin-top:0px;">
												<input type="text" name="contentraccoon_section_headings[0]" disabled data-name="contentraccoon_section_headings" placeholder="Enter heading or leave blank" autocomplete="off" />
											</div> 
											<div class="del-repeater-col"><i class="fa-solid fa-trash"></i>Remove Section</div>
										</div>
										
										<div class="button-container" style="order:999"> 
											<div class="button outline add-repeater-col"><i class="fa-solid fa-plus"></i>Add Another Section</div> 
										</div>
										
									</div>

								</div>
							</div>
							
						</div>
						-->

						<div class="creator-step" data-id="4">
							
							<h3>Review Post</h3> 
							
							<p>Here's a suggested post structure that's tailored according to your details.</p> 
							<p>Once you approve creation, it will take around 1-2 minutes for the whole process to complete.</p>
							<p>Keep this page open - when the process will be finished the post content will appear in your Wordpress editor.</p>
							
							<div id="contentraccoon_page-sections">
								
								<div id="contentraccoon_post_structure_title"></div>
								<div id="contentraccoon_post_structure_intro"></div>
								<div id="contentraccoon_post_structure_sections"></div>
								
							</div>
							
						</div>


						<div class="creator-step active" data-id="5">
							<div class="step-center" style="
							">	
								<div class="success">
									<div class="loading-inner"> 
										<div class="loader-text-1" style="display: none;">
											<span class="ia">S</span><span class="io">u</span><span class="ia">c</span><span class="io">c</span><span class="ia">e</span><span class="io">s</span><span class="ia">s</span><span class="io">!</span>
										</div>
										<div class="loader-text-2" style="">
											<span class="io">S</span><span class="ia">u</span><span class="io">c</span><span class="ia">c</span><span class="io">e</span><span class="ia">s</span><span class="io">s</span><span class="ia">!</span>
										</div> 
									</div> 
								</div>

								<img src="https://contentraccoon.com/images/raccoon_delivery.jpg" class="delivery-raccoon" style=""><p class="">"<strong class="post_name">{{post_title}}</strong>"<br/>will be delivered soon.</p>
								
								<?php
								$quotes = ["Slow and steady wins the race, <br/>even in loading bars.",
								"Patience is a virtue, <br/>especially in the world of technology.",
								"Loading bars remind us <br/>that sometimes progress takes time.",
								"Every loading bar brings us closer <br/>to our destination.",
								"Don't let the loading bar stress you out, <br/>it's just doing its job.",
								"A loading bar is like a caterpillar, <br/>slowly transforming into a beautiful butterfly.",
								"Waiting is not a waste of time, <br/>it's an opportunity to reflect <br/>and appreciate the present moment.",
								"The longer the loading bar, <br/>the more time we have to prepare ourselves <br/>for what's to come.",
								"The loading bar is a symbol of progress, <br/>reminding us that we're moving forward.",
								"Loading bars are like snowflakes, <br/>each one unique and beautiful in its own way.",
								"The loading bar is a reminder to be patient, <br/>even in the face of adversity.",
								"While you wait, <br/>take a moment to appreciate the small things in life.",
								"Great things take time, <br/>and this is no exception.",
								"Let's take a moment to appreciate the anticipation.",
								"This is like waiting for your cake to bake, <br/>but better!",
								"Good things come to those who wait, <br/>and you're about to experience something great.",
								"This isn't just any loading bar, <br/>it's a progress indicator for something amazing.",
								"Waiting builds patience, <br/>and patience leads to great things.",
								"The anticipation is half the fun, <br/>so enjoy the ride.",
								"The longer the wait, <br/>the sweeter the reward.",
								"Good things come to those who wait, <br/>and this is definitely a good thing."];
								
								$q = $quotes[rand(0,count($quotes)-1)];
								?> 
								<div style="font-style:italic;text-align:center;padding:30px 23% 5px;font-size:1.2em;">
									"<?php echo $q; ?>"
									<br/>
								</div>
								~ GPT-4
 
							</div>
						</div>


					</div>


					<div class="creator-steps-bottom">

						<div class="step-back" style="display:none;"  onclick='contentraccoon__go_to_step(-1)'><i class="fa-sharp fa-solid fa-arrow-left"></i><span>Previous</span></div>
						<div class="step-next"><span>Select Key Points</span><span class="dashicons dashicons-arrow-right-alt"></span></div>

					</div>

				</div>


			</div>
		
		</div>
			
		 
	</div>
	  
	<div id="contenraccoon-error-popup">
		<div class="contenraccoon-error-popup--inner">

			<div class="contenraccoon-error-popup--close">X</div>
			<div class="contenraccoon-error-popup--msg"><span></span><br/>Purchase Credits now or use lower Word Count to procceed.</div>
			<div class="contenraccoon-error-popup--buttons">
				<a href="https://contentraccoon.com/#pricing" target=_blank><button class="contentraccoon-button button">Purchase Credits</button></a>
			</div>

		</div>

	</div>

	<?php
}
add_action( 'admin_footer-post-new.php', 'add_html_to_post_screen' );


// Add top priority meta box to post edit screen
function contentraccoon_add_meta_box() {
    add_meta_box(
        'contentraccoon_add_meta_box',
        'ContentRaccoon',
        'contentraccoon_meta_box_callback',
        'post',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'contentraccoon_add_meta_box' );

// Callback function to display top priority meta box
function contentraccoon_meta_box_callback( $post ) {
    contentraccoon_form_element();
}


